@@ -101,6 +101,11 @@ import           Data.Maybe
 
 import           System.IO
                  ( Handle
+                 , TextEncoding
+                 , hSetBinaryMode
+                 , hSetEncoding
+                 , mkTextEncoding
+                 , utf8
                  , hPutStr
                  , hIsOpen
                  , hGetContents
@@ -463,10 +468,21 @@ completeCmd mbOut mbErr pHandle errorSpec = do
         mbOut' = slurp' mbOut :: Maybe (IO String)
         mbErr' = slurp' mbErr :: Maybe (IO String)
 
+    -- @todo: add encodings to the options structure, but only for
+    -- CreatePipe, and set them here:
+    let encOutTodo = utf8
+        encErrTodo = utf8
+
+    setEncodingMaybe (mbOut, encOutTodo) (mbErr, encErrTodo)
     io <- seqMaybeIO mbOut' mbErr' :: IO (Maybe String, Maybe String)
     exit <- makeExit <$> waitForProcess pHandle
     pure $ ResultsSyncSpawnOk exit io errorSpec
 
+setEncodingMaybe :: (Maybe Handle, TextEncoding) -> (Maybe Handle, TextEncoding) -> IO ()
+setEncodingMaybe (mb1, e1) (mb2, e2) = set' mb1 e1 >> set' mb2 e2 where
+    set' (Just h) e = hSetEncoding h e
+    set' _ _ = pure ()
+
 seqMaybeIO :: Maybe (IO String) -> Maybe (IO String) -> IO (Maybe String, Maybe String)
 seqMaybeIO a b = (,) <$> f a <*> f b where
     f (Just y) = pure . Just =<< y
